@@ -1,20 +1,28 @@
 ################################################################################
+#
+# $Project: /Tie-Hash-Indexed $
+# $Author: mhx $
+# $Date: 2003/11/02 15:11:06 +0100 $
+# $Revision: 2 $
+# $Snapshot: /Tie-Hash-Indexed/0.01 $
+# $Source: /lib/Tie/Hash/Indexed.pm $
+#
+################################################################################
 # 
-# Copyright (c) 2002-2016 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2003 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 # 
 ################################################################################
 
 package Tie::Hash::Indexed;
-use 5.004;
-use strict;
+use 5.00405;
 use DynaLoader;
 use Tie::Hash;
 use vars qw($VERSION @ISA);
 
 @ISA = qw(DynaLoader Tie::Hash);
-$VERSION = '0.05_04';
+$VERSION = do { my @r = '$Snapshot: /Tie-Hash-Indexed/0.01 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
 
 bootstrap Tie::Hash::Indexed $VERSION;
 
@@ -46,27 +54,6 @@ fast as Tie::IxHash. It's quite a lot faster when it comes
 to clearing or deleting entries from large hashes.
 Currently, only the plain tying mechanism is supported.
 
-=head1 ENVIRONMENT
-
-=head2 C<THI_DEBUG_OPT>
-
-If Tie::Hash::Indexed is built with debugging support, you
-can use this environment variable to specify debugging
-options. Currently, the only useful values you can pass
-in are C<d> or C<all>, which both enable debug output for
-the module.
-
-=head1 PROBLEMS
-
-As the data of Tie::Hash::Indexed objects is hidden inside
-the XS implementation, cloning/serialization is problematic.
-Tie::Hash::Indexed implements hooks for Storable, so cloning
-or serializing objects using Storable is safe.
-
-Tie::Hash::Indexed tries very hard to detect any corruption
-in its data at runtime. So if something goes wrong, you'll
-most probably receive an appropriate error message.
-
 =head1 BUGS
 
 If you find any bugs, Tie::Hash::Indexed doesn't seem to
@@ -82,7 +69,7 @@ If you're interested in what I currently plan to improve
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2016 Marcus Holland-Moritz. All rights reserved.
+Copyright (c) 2003 Marcus Holland-Moritz. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
